document.addEventListener('DOMContentLoaded', () => {
  const questions = [
    {
      question: "Has this person ever asked you for money?",
      weight: 5
    },
    {
      question: "Do they make excuses to not video chat?",
      weight: 4
    },
    {
      question: "Have they shared inconsistent information about themselves?",
      weight: 4
    },
    {
      question: "Did they declare strong feelings very quickly?",
      weight: 3
    },
    {
      question: "Do they pressure you to keep your relationship secret?",
      weight: 4
    }
  ];

  const questionsContainer = document.getElementById('questions');
  const submitButton = document.getElementById('submit-quiz');
  const resultsContainer = document.getElementById('results');
  const menuToggle = document.querySelector('.menu-toggle');
  const navLinks = document.querySelector('.nav-links');

  // Generate quiz questions
  questions.forEach((q, index) => {
    const questionDiv = document.createElement('div');
    questionDiv.className = 'question';
    questionDiv.innerHTML = `
      <p>${q.question}</p>
      <select id="q${index}">
        <option value="">Select an answer</option>
        <option value="yes">Yes</option>
        <option value="no">No</option>
        <option value="unsure">Unsure</option>
      </select>
    `;
    questionsContainer.appendChild(questionDiv);
  });

  // Handle quiz submission
  submitButton.addEventListener('click', () => {
    let riskScore = 0;
    let answeredAll = true;

    questions.forEach((q, index) => {
      const answer = document.getElementById(`q${index}`).value;
      if (!answer) {
        answeredAll = false;
        return;
      }
      if (answer === 'yes') {
        riskScore += q.weight;
      } else if (answer === 'unsure') {
        riskScore += q.weight / 2;
      }
    });

    if (!answeredAll) {
      alert('Please answer all questions');
      return;
    }

    const maxScore = questions.reduce((acc, q) => acc + q.weight, 0);
    const riskPercentage = (riskScore / maxScore) * 100;

    resultsContainer.className = 'results-container';
    resultsContainer.innerHTML = `
      <h3>Risk Assessment</h3>
      <p>Based on your answers, this relationship shows a ${riskPercentage.toFixed(1)}% risk level.</p>
      <p>${getRiskMessage(riskPercentage)}</p>
    `;
  });

  // Mobile menu toggle
  menuToggle.addEventListener('click', () => {
    navLinks.classList.toggle('active');
  });

  // Helper function for risk messages
  function getRiskMessage(risk) {
    if (risk >= 75) {
      return "High Risk: This relationship shows multiple serious red flags. We strongly recommend ending communication and seeking support.";
    } else if (risk >= 50) {
      return "Moderate Risk: There are concerning signs. Proceed with extreme caution and consider seeking advice from trusted friends or family.";
    } else if (risk >= 25) {
      return "Low-Moderate Risk: While there are some concerns, maintain awareness and continue to evaluate the relationship carefully.";
    } else {
      return "Low Risk: While this relationship shows fewer red flags, always maintain healthy boundaries and stay vigilant.";
    }
  }
});
